@@ -1,3 +1,5 @@
+//! Widget types and the core component collection
+
 pub mod component;
 pub mod context;
 pub mod node;
@@ -340,12 +342,15 @@ pub fn setup(app: &mut Application) {
     app.register_props::<f64>("f64");
     app.register_props::<bool>("bool");
     app.register_props::<String>("String");
+    app.register_props::<component::containers::anchor_box::AnchorProps>("AnchorProps");
+    app.register_props::<component::containers::anchor_box::PivotBoxProps>("PivotBoxProps");
     app.register_props::<component::containers::content_box::ContentBoxProps>("ContentBoxProps");
     app.register_props::<component::containers::flex_box::FlexBoxProps>("FlexBoxProps");
     app.register_props::<component::containers::grid_box::GridBoxProps>("GridBoxProps");
     app.register_props::<component::containers::horizontal_box::HorizontalBoxProps>(
         "HorizontalBoxProps",
     );
+    app.register_props::<component::containers::hidden_box::HiddenBoxProps>("HiddenBoxProps");
     app.register_props::<component::containers::scroll_box::ScrollBoxOwner>("ScrollBoxOwner");
     app.register_props::<component::containers::scroll_box::SideScrollbarsProps>(
         "SideScrollbarsProps",
@@ -353,15 +358,18 @@ pub fn setup(app: &mut Application) {
     app.register_props::<component::containers::scroll_box::SideScrollbarsState>(
         "SideScrollbarsState",
     );
-    app.register_props::<component::containers::portal_box::PortalBoxProps>("PortalBoxProps");
+    app.register_props::<component::containers::portal_box::PortalsContainer>("PortalsContainer");
     app.register_props::<component::containers::size_box::SizeBoxProps>("SizeBoxProps");
     app.register_props::<component::containers::switch_box::SwitchBoxProps>("SwitchBoxProps");
+    app.register_props::<component::containers::tabs_box::TabsBoxProps>("TabsBoxProps");
+    app.register_props::<component::containers::tooltip_box::TooltipState>("TooltipState");
     app.register_props::<component::containers::variant_box::VariantBoxProps>("VariantBoxProps");
     app.register_props::<component::containers::vertical_box::VerticalBoxProps>("VerticalBoxProps");
     app.register_props::<component::containers::wrap_box::WrapBoxProps>("WrapBoxProps");
     app.register_props::<component::image_box::ImageBoxProps>("ImageBoxProps");
     app.register_props::<component::interactive::button::ButtonProps>("ButtonProps");
     app.register_props::<component::interactive::button::ButtonNotifyProps>("ButtonNotifyProps");
+    app.register_props::<component::interactive::input_field::TextInputMode>("TextInputMode");
     app.register_props::<component::interactive::input_field::TextInputProps>("TextInputProps");
     app.register_props::<component::interactive::input_field::TextInputNotifyProps>(
         "TextInputNotifyProps",
@@ -388,6 +396,8 @@ pub fn setup(app: &mut Application) {
     app.register_props::<unit::flex::FlexBoxItemLayout>("FlexBoxItemLayout");
     app.register_props::<unit::grid::GridBoxItemLayout>("GridBoxItemLayout");
 
+    app.register_component("anchor_box", component::containers::anchor_box::anchor_box);
+    app.register_component("pivot_box", component::containers::anchor_box::pivot_box);
     app.register_component(
         "nav_content_box",
         component::containers::content_box::nav_content_box,
@@ -429,6 +439,18 @@ pub fn setup(app: &mut Application) {
         component::containers::switch_box::nav_switch_box,
     );
     app.register_component("switch_box", component::containers::switch_box::switch_box);
+    app.register_component(
+        "nav_tabs_box",
+        component::containers::tabs_box::nav_tabs_box,
+    );
+    app.register_component(
+        "tooltip_box",
+        component::containers::tooltip_box::tooltip_box,
+    );
+    app.register_component(
+        "portals_tooltip_box",
+        component::containers::tooltip_box::portals_tooltip_box,
+    );
     app.register_component(
         "variant_box",
         component::containers::variant_box::variant_box,
@@ -456,6 +478,22 @@ pub fn setup(app: &mut Application) {
     app.register_component("text_box", component::text_box::text_box);
 }
 
+/// Helper to manually create a [`WidgetComponent`][crate::widget::component::WidgetComponent]
+/// struct from a function.
+///
+/// Users will not usually need this macro, but it can be useful in some advanced cases or where you
+/// don't want to use the [`widget`] macro.
+///
+/// # Example
+///
+/// ```
+/// # use raui_core::prelude::*;
+/// let component: WidgetComponent = make_widget!(my_component);
+///
+/// fn my_component(context: WidgetContext) -> WidgetNode {
+///     todo!("Make an awesome widget")
+/// }
+/// ```
 #[macro_export]
 macro_rules! make_widget {
     ($type_id:path) => {{
@@ -465,6 +503,51 @@ macro_rules! make_widget {
     }};
 }
 
+/// Create a [`WidgetNode`] struct from a custom widget tree DSL
+///
+/// The `widget` macro is primarily used to construct widget trees as the return value of
+/// components.
+///
+/// # Example
+///
+/// ```rust
+/// # use raui_core::prelude::*;
+/// # fn my_component(_: WidgetContext) -> WidgetNode { todo!() }
+/// # fn component_1(_: WidgetContext) -> WidgetNode { todo!() }
+/// # fn popup(_: WidgetContext) -> WidgetNode { todo!() }
+/// # fn component_2(_: WidgetContext) -> WidgetNode { todo!() }
+/// # fn component_3(_: WidgetContext) -> WidgetNode { todo!() }
+/// # fn test() -> WidgetNode {
+/// # let my_component_props = Props::new(());
+/// # let my_component_shared_props = Props::new(());
+/// # let component_1_props = Props::new(());
+/// # let popup_props = Props::new(());
+/// # let component_2_props = Props::new(());
+/// # let component_3_props = Props::new(());
+///
+/// // You can create [`WidgetNode`]'s and assign them to variables
+/// let popup_widget = widget! {
+///     (popup: {popup_props})
+/// };
+///
+/// widget! {
+///     // parenthesis are used around components and they each _may_ have a key,
+///     // props, shared props, listed children, and/or named children. Everything is,
+///     // optional.
+///     (#{"widget_key"} my_component: {my_component_props} | {my_component_shared_props} {
+///         // named children
+///         content = (component_1: {component_1_props})
+///     } [
+///         // listed children
+///         (component_2: {component_2_props})
+///         (component_3: {component_3_props})
+///
+///         // You can also use `{variable_name}` syntax to expand variables into a widget
+///         {popup_widget}
+///     ])
+/// }
+/// # }
+/// ```
 #[macro_export]
 macro_rules! widget {
     {()} => ($crate::widget::node::WidgetNode::None);
@@ -536,7 +619,7 @@ macro_rules! widget {
             let mut named_slots = std::collections::HashMap::new();
             $(
                 $(
-                    let widget = $crate::widget_wrap!{$named_slot_widget};
+                    let widget = $crate::widget!{@wrap $named_slot_widget};
                     if widget.is_some() {
                         let name = stringify!($named_slot_name).to_owned();
                         named_slots.insert(name, widget);
@@ -550,7 +633,7 @@ macro_rules! widget {
             )?
             $(
                 $(
-                    let widget = $crate::widget_wrap!{$listed_slot_widget};
+                    let widget = $crate::widget!{@wrap $listed_slot_widget};
                     if widget.is_some() {
                         listed_slots.push(widget);
                     }
@@ -563,33 +646,59 @@ macro_rules! widget {
                 idref,
                 props,
                 shared_props,
-                named_slots,
                 listed_slots,
+                named_slots,
             };
             $crate::widget::node::WidgetNode::Component(component)
         }
     };
-}
-
-#[macro_export]
-macro_rules! widget_wrap {
-    ({$expr:expr}) => {
+    (@wrap {$expr:expr}) => {
         $crate::widget::node::WidgetNode::from($expr)
     };
-    ($tree:tt) => {
+    (@wrap $tree:tt) => {
         $crate::widget!($tree)
     };
 }
 
-#[macro_export]
-macro_rules! destruct {
-    {$type_id:path { $($prop:ident),+ } ($value:expr) => $code:block} => {
-        match $value {
-            $type_id { $( $prop ),+ , .. } => $code
-        }
-    };
-}
-
+/// A helper for getting the named children out of a widget context
+///
+/// # Example
+///
+/// ```
+/// # use raui_core::prelude::*;
+/// fn my_component(context: WidgetContext) -> WidgetNode {
+///     // Destructure our context to get our named slots
+///     let WidgetContext {
+///         named_slots,
+///         ..
+///     } = context;
+///
+///     // Unpack our named `body` slot
+///     unpack_named_slots!(named_slots => body);
+///
+///     widget! {
+///         (content_box {
+///             // insert our body slot in the content box
+///             content = {body}
+///         })
+///     }
+/// }
+/// ```
+///
+/// You can also unpack multiple slots at a time like this:
+///
+/// ```
+/// # use raui_core::prelude::*;
+/// # fn my_component(context: WidgetContext) -> WidgetNode {
+/// #    let WidgetContext {
+/// #        named_slots,
+/// #        ..
+/// #    } = context;
+/// // Unpack the `header`, `body`, and `footer` slots
+/// unpack_named_slots!(named_slots => { header, body, footer });
+/// #    widget!(())
+/// # }
+/// ```
 #[macro_export]
 macro_rules! unpack_named_slots {
     ($map:expr => $name:ident) => {
